@@ -135,7 +135,7 @@ MainWindow::initLogging ()
                         this     , SLOT(onCleanupLogsArray()));
     Q_ASSERT(rv); Q_UNUSED(rv);
 
-    setStatus("Using qgvdial version 0.3.868");
+    setStatus("Using qgvdial version 0.3.874");
 }//MainWindow::initLogging
 
 /** Log information to console and to log file
@@ -143,7 +143,7 @@ MainWindow::initLogging ()
  * @param strText Text to be logged
  */
 void
-MainWindow::log (const QDateTime &dt, int level, QString &strText)
+MainWindow::log (const QDateTime & /*dt*/, int /*level*/, QString &strText)
 {
     if (!strPass.isEmpty() && strText.contains(strPass)) {
         strText.replace(strPass, "XXXXXX");
@@ -510,7 +510,7 @@ MainWindow::initQML ()
     bool bTempFalse = false;
     int iTempZero = 0;
 
-    // Prepare the glabally accessible variants for QML.
+    // Prepare the globally accessible variants for QML.
     QDeclarativeContext *ctx = this->rootContext();
     ctx->setContextProperty ("g_bShowMsg", bTempFalse);
     ctx->setContextProperty ("g_registeredPhonesModel", &modelRegNumber);
@@ -525,7 +525,7 @@ MainWindow::initQML ()
     // Initialize the QML view
     this->setSource (QUrl(osd.getMainQML()));
 
-    onDesktopResized ();
+    onOrientationChanged (osd.getOrientation ());
     this->setResizeMode (QDeclarativeView::SizeRootObjectToView);
 
     this->setUsername ("example@gmail.com");
@@ -539,80 +539,79 @@ MainWindow::initQML ()
         return;
     }
 
-    bool bOk;
+    bool rv;
     // Connect all signals to slots in this class.
-    bOk = connect (gObj, SIGNAL (sigCall (QString)),
+    rv = connect (gObj, SIGNAL (sigCall (QString)),
                    this, SLOT   (dialNow (QString)));
-    Q_ASSERT(bOk);
-    if (!bOk) { exit(1); }
-    bOk = connect (
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+    rv = connect (
         gObj, SIGNAL (sigText (const QString &, const QString &)),
         this, SLOT   (onSigText (const QString &, const QString &)));
-    Q_ASSERT(bOk);
-    if (!bOk) { exit(1); }
-    bOk = connect (gObj, SIGNAL (sigVoicemail (QString)),
-                   this, SLOT   (retrieveVoicemail (const QString &)));
-    Q_ASSERT(bOk);
-    if (!bOk) { exit(1); }
-    bOk = connect (gObj, SIGNAL (sigVmailPlayback (int)),
-                   this, SLOT   (onSigVmailPlayback (int)));
-    Q_ASSERT(bOk);
-    if (!bOk) { exit(1); }
-    bOk = connect (gObj, SIGNAL (sigSelChanged (int)),
-                   this, SLOT   (onRegPhoneSelectionChange (int)));
-    Q_ASSERT(bOk);
-    if (!bOk) { exit(1); }
-    bOk = connect (gObj   , SIGNAL (sigInboxSelect (QString)),
-                   &oInbox, SLOT   (onInboxSelected (const QString &)));
-    Q_ASSERT(bOk);
-    if (!bOk) { exit(1); }
-    bOk = connect (gObj   , SIGNAL (sigMarkAsRead (QString)),
-                   &oInbox, SLOT   (onSigMarkAsRead (const QString &)));
-    Q_ASSERT(bOk);
-    if (!bOk) { exit(1); }
-    bOk = connect (gObj, SIGNAL (sigCloseVmail ()),
-                   this, SLOT   (onSigCloseVmail ()));
-    Q_ASSERT(bOk);
-    if (!bOk) { exit(1); }
-    bOk = connect (gObj, SIGNAL (sigHide ()),
-                   this, SLOT   (onSigHide ()));
-    Q_ASSERT(bOk);
-    if (!bOk) { exit(1); }
-    bOk = connect (gObj, SIGNAL (sigQuit ()),
-                   this, SLOT   (on_actionE_xit_triggered ()));
-    Q_ASSERT(bOk);
-    if (!bOk) { exit(1); }
-    if (!bOk) { exit(1); }
-    bOk = connect (gObj, SIGNAL (sigMsgBoxDone(bool)),
-                   this, SLOT (onSigMsgBoxDone(bool)));
-    Q_ASSERT(bOk);
-    if (!bOk) { exit(1); }
-    bOk = connect (
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+    rv = connect (gObj, SIGNAL (sigVoicemail (QString)),
+                  this, SLOT   (retrieveVoicemail (const QString &)));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+    rv = connect (gObj, SIGNAL (sigVmailPlayback (int)),
+                  this, SLOT   (onSigVmailPlayback (int)));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+    rv = connect (gObj, SIGNAL (sigSelChanged (int)),
+                  this, SLOT   (onRegPhoneSelectionChange (int)));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+    rv = connect (gObj   , SIGNAL (sigInboxSelect (QString)),
+                  &oInbox, SLOT   (onInboxSelected (const QString &)));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+    rv = connect (gObj   , SIGNAL (sigMarkAsRead (QString)),
+                  &oInbox, SLOT   (onSigMarkAsRead (const QString &)));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+    rv = connect (gObj, SIGNAL (sigCloseVmail ()),
+                  this, SLOT   (onSigCloseVmail ()));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+    rv = connect (gObj, SIGNAL (sigHide ()),
+                  this, SLOT   (onSigHide ()));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+    rv = connect (gObj, SIGNAL (sigQuit ()),
+                  this, SLOT   (on_actionE_xit_triggered ()));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+    if (!rv) { exit(1); }
+    rv = connect (gObj, SIGNAL (sigMsgBoxDone(bool)),
+                  this, SLOT (onSigMsgBoxDone(bool)));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+    rv = connect (
         gObj      , SIGNAL  (sigSearchContacts(const QString &)),
         &oContacts, SLOT (onSearchQueryChanged(const QString &)));
-    Q_ASSERT(bOk);
-    if (!bOk) { exit(1); }
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
 
     // Now do the settings page
     if (!connectSettingsSignals ()) {
         exit (1);
     }
 
-#if MOBILE_OS
-    bOk = connect(qApp->desktop(), SIGNAL(resized(int)),
-                  this           , SLOT(onDesktopResized()));
-    Q_ASSERT(bOk);
-    if (!bOk) { exit(1); }
-#endif
+    rv = connect (&osd, SIGNAL(orientationChanged(OsIndependentOrientation)),
+                  this, SLOT(onOrientationChanged(OsIndependentOrientation)));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
 
 #if DESKTOP_OS
     Qt::WindowFlags flags = this->windowFlags ();
     flags |= Qt::CustomizeWindowHint;
-    flags &= ~(Qt::WindowTitleHint | Qt::WindowSystemMenuHint |
-               Qt::WindowMinimizeButtonHint | Qt::WindowMaximizeButtonHint |
-               Qt::WindowCloseButtonHint);
+    flags &= ~(Qt::WindowTitleHint | Qt::WindowMaximizeButtonHint);
     this->setWindowFlags (flags);
     this->setFixedSize(this->size());
+
+    gObj = getQMLObject ("CloseButton");
+    gObj->setProperty ("visible", (bool)false);
 #endif
 
 }//MainWindow::initQML
@@ -2138,7 +2137,7 @@ MainWindow::onTwoStepAuthentication(AsyncTaskToken *token)
 }//MainWindow::onTwoStepAuthentication
 
 void
-MainWindow::onDesktopResized()
+MainWindow::onOrientationChanged(OsIndependentOrientation o)
 {
     QObject *pMain = this->rootObject ();
     if (NULL == pMain) {
@@ -2150,7 +2149,7 @@ MainWindow::onDesktopResized()
     QRect rect = osd.getStartingSize ();
     pMain->setProperty("height", rect.height());
     pMain->setProperty("width", rect.width());
-}//MainWindow::onDesktopResized
+}//MainWindow::resetWindowSize
 
 QObject *
 MainWindow::getQMLObject(const char *pageName)
@@ -2263,7 +2262,7 @@ MainWindow::onGetLogLocation(bool success, const QByteArray &response,
         QDomElement appVerTag = doc.createElement("Version");
         paramsTag.appendChild(appVerTag);
 
-        QDomText appVerText = doc.createTextNode("0.3.868");
+        QDomText appVerText = doc.createTextNode("0.3.874");
         appVerTag.appendChild(appVerText);
 
         QDomElement osVerTag = doc.createElement("OsVer");
@@ -2327,7 +2326,7 @@ MainWindow::onLogPosted(bool success, const QByteArray &response,
         QDateTime dt = token->inParams["date"].toDateTime();
         QString body = QString("Logs captured at %1 \n")
                                 .arg (dt.toUTC ().toString (Qt::ISODate));
-        body += "qgvdial version = 0.3.868 \n";
+        body += "qgvdial version = 0.3.874 \n";
         body += QString("OS: %1 \n").arg(osd.getOSDetails());
         body += QString("Logs are in %1 \n").arg(strReply);
         url.addQueryItem ("body", body);
